@@ -40,7 +40,8 @@ from six import string_types
 from ._tables import (Table,
                       _default_ms,
                       _default_ms_subtable,
-                      _required_ms_desc)
+                      _required_ms_desc,
+                      _complete_ms_desc)
 
 from .tablehelper import (_add_prefix, _remove_prefix, _do_remove_prefix,
                           _format_row)
